document.addEventListener('DOMContentLoaded', () => {
    // Initialize chatbot
    const chatbot = {
        init() {
            this.createChatbotUI();
            this.bindEvents();
        },

        createChatbotUI() {
            const chatbotContainer = document.createElement('div');
            chatbotContainer.className = 'chatbot-container';
            chatbotContainer.innerHTML = `
                <div class="chatbot-toggle">
                    <span class="chatbot-icon">💬</span>
                </div>
                <div class="chatbot-box hidden">
                    <div class="chatbot-header">
                        <h3>MID PETROLEUM Assistant</h3>
                        <button class="close-chat">×</button>
                    </div>
                    <div class="chatbot-messages"></div>
                    <div class="chatbot-input">
                        <input type="text" placeholder="Type your message...">
                        <button class="send-message">Send</button>
                        <button class="voice-input">🎤</button>
                    </div>
                </div>
            `;
            document.body.appendChild(chatbotContainer);
        },

        bindEvents() {
            const toggle = document.querySelector('.chatbot-toggle');
            const closeBtn = document.querySelector('.close-chat');
            const chatbox = document.querySelector('.chatbot-box');
            const sendBtn = document.querySelector('.send-message');
            const input = document.querySelector('.chatbot-input input');

            toggle.addEventListener('click', () => {
                chatbox.classList.toggle('hidden');
            });

            closeBtn.addEventListener('click', () => {
                chatbox.classList.add('hidden');
            });

            sendBtn.addEventListener('click', () => {
                if (input.value.trim()) {
                    this.handleMessage(input.value);
                    input.value = '';
                }
            });
        },

        handleMessage(message) {
            // Simple response logic - expand as needed
            const responses = {
                'hello': 'Hello! How can I help you today?',
                'services': 'We offer petroleum distribution, energy solutions, and technical support.',
                'contact': 'You can reach us at info@midpetroleum.com or call +1 234 567 8900.',
                'default': 'Thank you for your message. How else can I assist you?'
            };

            const response = responses[message.toLowerCase()] || responses.default;
            this.addMessage('user', message);
            setTimeout(() => {
                this.addMessage('bot', response);
            }, 500);
        },

        addMessage(sender, message) {
            const messagesContainer = document.querySelector('.chatbot-messages');
            const messageDiv = document.createElement('div');
            messageDiv.className = `message ${sender}-message`;
            messageDiv.textContent = message;
            messagesContainer.appendChild(messageDiv);
            messagesContainer.scrollTop = messagesContainer.scrollHeight;
        }
    };

    chatbot.init();

    // Handle file uploads
    const uploadForm = document.querySelector('.upload-form');
    if (uploadForm) {
        uploadForm.addEventListener('submit', (e) => {
            e.preventDefault();
            const fileInput = document.getElementById('file-upload');
            if (fileInput.files.length > 0) {
                // Simulate upload
                alert('File uploaded successfully!');
                fileInput.value = '';
            }
        });
    }

    // Smooth scroll for navigation links
    document.querySelectorAll('a[href^="#"]').forEach(anchor => {
        anchor.addEventListener('click', function (e) {
            e.preventDefault();
            document.querySelector(this.getAttribute('href')).scrollIntoView({
                behavior: 'smooth'
            });
        });
    });
});